/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*             UNIDAD DE EVALUACIN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIN GENERAL DE MEDICIN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIN DE TRATAMIENTO DE DATOS
/*
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                     TERCER GRADO DE PRIMARIA (Excale 03)
/*
/*                              **** ESPAOL ****
/*
/*                     Ciclo escolar evaluado: 2013 - 2014
/*_____________________________________________________________________________
/*
/*
/*        SINTAXIS PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE ESPAOL
/*                                  EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale03_2014_Alum_Esp.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale03_2014_Alum_Esp.txt
/*         as como el archivo Excale03_2014_Alum_Esp.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale03_2014_Alum_Esp.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale03_2014_Alum_Esp.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Direccin de Tratamiento de Datos
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 32025
/*      Domicilio: Av. Barranca del Muerto no. 341, 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN:   01 DE SEPTIEMBRE 2015
/*
/*  ****************************************************************************/


LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale03_2014_Alum_Esp.TXT";

PROC FORMAT;
     VALUE id_entF  1      = "Aguascalientes"
                    2      = "Baja California"
                    3      = "Baja California Sur"
                    4      = "Campeche"
                    5      = "Coahuila"
                    6      = "Colima"
                    7      = "Chiapas"
                    8      = "Chihuahua"
                    9      = "Distrito Federal"
                    10     = "Durango"
                    11     = "Guanajuato"
                    12     = "Guerrero"
                    13     = "Hidalgo"
                    14     = "Jalisco"
                    15     = "Mxico"
                    16     = "Michoacn"
                    17     = "Morelos"
                    18     = "Nayarit"
                    19     = "Nuevo Len"
                    20     = "Oaxaca"
                    21     = "Puebla"
                    22     = "Quertaro"
                    23     = "Quintana Roo"
                    24     = "San Luis Potos"
                    25     = "Sinaloa"
                    26     = "Sonora"
                    27     = "Tabasco"
                    28     = "Tamaulipas"
                    29     = "Tlaxcala"
                    30     = "Veracruz"
                    31     = "Yucatn"
                    32     = "Zacatecas";
     VALUE id_modF  1      = "Urbana Pblica"
                    2      = "Rural Pblica"
                    3      = "Educacin Indgena"
                    4      = "Curso Comunitario"
                    5      = "Privada"
                    6      = "General"
                    7      = "Tcnica"
                    8      = "Telesecundaria"
                    9      = "Privada";
     VALUE $modF    "UP"   = "Urbano Pblico"
                    "RP"   = "Rural Pblico"
                    "EI"   = "Educacin Indgena"
                    "CC"   = "Cursos Comunitarios"
                    "UPV"  = "Privada"
                    "GRAL" = "General"
                    "TEC"  = "Tcnica"
                    "TV"   = "Telesecundaria"
                    "PRIV" = "Privada";
     VALUE $entestF "999"  = "Respuesta omitida";
     VALUE sexoF    1      = "Hombre"
                    2      = "Mujer"
                    8      = "Respuesta mltiple"
                    9      = "Respuesta omitida";
     VALUE edad_acF 98     = "Respuesta mltiple"
                    99     = "Respuesta omitida";
     VALUE mes_nacF 1      = "Enero"
                    2      = "Febrero"
                    3      = "Marzo"
                    4      = "Abril"
                    5      = "Mayo"
                    6      = "Junio"
                    7      = "Julio"
                    8      = "Agosto"
                    9      = "Septiembre"
                    10     = "Octubre"
                    11     = "Noviembre"
                    12     = "Diciembre"
                    98     = "Respuesta mltiple"
                    99     = "Respuesta omitida";
     VALUE edadF    99     = "Respuesta omitida";
     VALUE edadCF   1      = "8 aos o menos"
                    2      = "9 aos"
                    3      = "10 aos"
                    4      = "11 aos o ms"
                    9      = "Respuesta omitida";
     VALUE edadNF   1      = "Edad normativa"
                    2      = "Extra-edad"
                    9      = "Respuesta omitida";
     VALUE edadAF   0      = "Sin edad anticipada"
                    1      = "Edad anticipada"
                    9      = "Respuesta omitida";
     VALUE edadEF   0      = "Sin extra edad severa"
                    1      = "Extra edad severa"
                    9      = "Respuesta omitida";
     VALUE docenF   99999  = "Respuesta omitida";
     VALUE reactF   0      = "Fallo"
                    1      = "Acierto"
                    5      = "Reactivo no alcanzado (se considera como no administrado)"
                    6      = "Reactivo no administrado por error de impresin"
                    7      = "Reactivo no administrado (No se incluy en su cuadernillo de examen)";
     VALUE nvlF     1      = "Por debajo del nivel bsico"
                    2      = "Bsico"
                    3      = "Medio"
                    4      = "Avanzado";
     VALUE nvblF    0      = "Por debajo del nivel bsico"
                    1      = "Al menos el nivel bsico";
     VALUE nvmlF    0      = "Por debajo del nivel medio"
                    1      = "Al menos el nivel medio";
RUN;



DATA INEE.Excale03_2014_Alum_Esp;
   LENGTH
       NACIONAL   3
       ESCUELA    4
       ID_ENT     3
       NOM_ENT    $19
       ID_MOD     3
       MOD        $4
       ESTRATO    $7
       ENTEST     $6
       ALUMNO     5
       ID_INSTR   $15
       SEXO       3
       EDAD_AC    3
       MES_NAC    3
       EDAD       8
       EDAD_ACC   3
       EDAD_N     3
       EDAD_ANT   3
       EDAD_EES   3
       W_ALU      8
       DOCENTE    5
       PEA_01     3
       PEA_02     3
       PEA_03     3
       PEA_04     3
       PEA_05     3
       PEA_06     3
       PEA_07     3
       PEA_08     3
       PEA_09     3
       PEA_10     3
       PEA_11     3
       PEA_12     3
       PEA_13     3
       PEB_01     3
       PEB_03     3
       PEB_04     3
       PEB_05     3
       PEB_06     3
       PEB_07     3
       PEB_08     3
       PEB_09     3
       PEB_10     3
       PEB_11     3
       PEB_12     3
       PEB_13     3
       PEC_01     3
       PEC_02     3
       PEC_03     3
       PEC_04     3
       PEC_05     3
       PEC_06     3
       PEC_07     3
       PEC_08     3
       PEC_09     3
       PEC_10     3
       PEC_11     3
       PEC_13     3
       PED_01     3
       PED_02     3
       PED_03     3
       PED_04     3
       PED_05     3
       PED_06     3
       PED_08     3
       PED_09     3
       PED_10     3
       PED_11     3
       PED_12     3
       PED_13     3
       PEE_01     3
       PEE_03     3
       PEE_04     3
       PEE_05     3
       PEE_06     3
       PEE_07     3
       PEE_08     3
       PEE_09     3
       PEE_10     3
       PEE_11     3
       PEE_12     3
       PEE_13     3
       PEF_01     3
       PEF_02     3
       PEF_03     3
       PEF_04     3
       PEF_05     3
       PEF_06     3
       PEF_07     3
       PEF_08     3
       PEF_09     3
       PEF_10     3
       PEF_11     3
       PEF_12     3
       PEF_13     3
       PEF_14     3
       PEG_01     3
       PEG_03     3
       PEG_04     3
       PEG_05     3
       PEG_06     3
       PEG_07     3
       PEG_08     3
       PEG_09     3
       PEG_10     3
       PEG_12     3
       PEG_13     3
       PEG_14     3
       PV1ESP     8
       PV2ESP     8
       PV3ESP     8
       PV4ESP     8
       PV5ESP     8
       ESPNVL1    3
       ESPNVL2    3
       ESPNVL3    3
       ESPNVL4    3
       ESPNVL5    3
       ESPNVBL1   3
       ESPNVBL2   3
       ESPNVBL3   3
       ESPNVBL4   3
       ESPNVBL5   3
       ESPNVML1   3
       ESPNVML2   3
       ESPNVML3   3
       ESPNVML4   3
       ESPNVML5   3
       WVARSTRR   3
       W_FSTR1    8
       W_FSTR2    8
       W_FSTR3    8
       W_FSTR4    8
       W_FSTR5    8
       W_FSTR6    8
       W_FSTR7    8
       W_FSTR8    8
       W_FSTR9    8
       W_FSTR10   8
       W_FSTR11   8
       W_FSTR12   8
       W_FSTR13   8
       W_FSTR14   8
       W_FSTR15   8
       W_FSTR16   8
       W_FSTR17   8
       W_FSTR18   8
       W_FSTR19   8
       W_FSTR20   8
       W_FSTR21   8
       W_FSTR22   8
       W_FSTR23   8
       W_FSTR24   8
       W_FSTR25   8
       W_FSTR26   8
       W_FSTR27   8
       W_FSTR28   8
       W_FSTR29   8
       W_FSTR30   8
       W_FSTR31   8
       W_FSTR32   8
       W_FSTR33   8
       W_FSTR34   8
       W_FSTR35   8
       W_FSTR36   8
       W_FSTR37   8
       W_FSTR38   8
       W_FSTR39   8
       W_FSTR40   8
       W_FSTR41   8
       W_FSTR42   8
       W_FSTR43   8
       W_FSTR44   8
       W_FSTR45   8
       W_FSTR46   8
       W_FSTR47   8
       W_FSTR48   8
       W_FSTR49   8
       W_FSTR50   8
       W_FSTR51   8
       W_FSTR52   8
       W_FSTR53   8
       W_FSTR54   8
       W_FSTR55   8
       W_FSTR56   8
       W_FSTR57   8
       W_FSTR58   8
       W_FSTR59   8
       W_FSTR60   8
       W_FSTR61   8
       W_FSTR62   8
       W_FSTR63   8
       W_FSTR64   8
       W_FSTR65   8
       W_FSTR66   8
       W_FSTR67   8
       W_FSTR68   8
       W_FSTR69   8
       W_FSTR70   8
       W_FSTR71   8
       W_FSTR72   8
       W_FSTR73   8
       W_FSTR74   8
       W_FSTR75   8
       W_FSTR76   8
       W_FSTR77   8
       W_FSTR78   8
       W_FSTR79   8
       W_FSTR80   8
       W_FSTR81   8
       W_FSTR82   8
       W_FSTR83   8
       W_FSTR84   8
       W_FSTR85   8
       W_FSTR86   8
       W_FSTR87   8
       W_FSTR88   8
       W_FSTR89   8
       W_FSTR90   8
       W_FSTR91   8
       W_FSTR92   8
       W_FSTR93   8
       W_FSTR94   8
       W_FSTR95   8
       W_FSTR96   8
       W_FSTR97   8
       W_FSTR98   8
       W_FSTR99   8
       W_FSTR100  8
;



INFILE alum MISSOVER LINESIZE = 1346;
   INPUT
      NACIONAL      1 - 1
      ESCUELA       2 - 5
      ID_ENT        6 - 7
      NOM_ENT       8 - 27
      ID_MOD       28 - 28
      MOD          29 - 32
      ESTRATO      33 - 39
      ENTEST       40 - 45
      ALUMNO       46 - 50
      ID_INSTR     51 - 65
      SEXO         66 - 66
      EDAD_AC      67 - 68
      MES_NAC      69 - 70
      EDAD         71 - 81
      EDAD_ACC     82 - 82
      EDAD_N       83 - 83
      EDAD_ANT     84 - 84
      EDAD_EES     85 - 85
      W_ALU        86 - 96
      DOCENTE      97 - 101
      PEA_01      102 - 102
      PEA_02      103 - 103
      PEA_03      104 - 104
      PEA_04      105 - 105
      PEA_05      106 - 106
      PEA_06      107 - 107
      PEA_07      108 - 108
      PEA_08      109 - 109
      PEA_09      110 - 110
      PEA_10      111 - 111
      PEA_11      112 - 112
      PEA_12      113 - 113
      PEA_13      114 - 114
      PEB_01      115 - 115
      PEB_03      116 - 116
      PEB_04      117 - 117
      PEB_05      118 - 118
      PEB_06      119 - 119
      PEB_07      120 - 120
      PEB_08      121 - 121
      PEB_09      122 - 122
      PEB_10      123 - 123
      PEB_11      124 - 124
      PEB_12      125 - 125
      PEB_13      126 - 126
      PEC_01      127 - 127
      PEC_02      128 - 128
      PEC_03      129 - 129
      PEC_04      130 - 130
      PEC_05      131 - 131
      PEC_06      132 - 132
      PEC_07      133 - 133
      PEC_08      134 - 134
      PEC_09      135 - 135
      PEC_10      136 - 136
      PEC_11      137 - 137
      PEC_13      138 - 138
      PED_01      139 - 139
      PED_02      140 - 140
      PED_03      141 - 141
      PED_04      142 - 142
      PED_05      143 - 143
      PED_06      144 - 144
      PED_08      145 - 145
      PED_09      146 - 146
      PED_10      147 - 147
      PED_11      148 - 148
      PED_12      149 - 149
      PED_13      150 - 150
      PEE_01      151 - 151
      PEE_03      152 - 152
      PEE_04      153 - 153
      PEE_05      154 - 154
      PEE_06      155 - 155
      PEE_07      156 - 156
      PEE_08      157 - 157
      PEE_09      158 - 158
      PEE_10      159 - 159
      PEE_11      160 - 160
      PEE_12      161 - 161
      PEE_13      162 - 162
      PEF_01      163 - 163
      PEF_02      164 - 164
      PEF_03      165 - 165
      PEF_04      166 - 166
      PEF_05      167 - 167
      PEF_06      168 - 168
      PEF_07      169 - 169
      PEF_08      170 - 170
      PEF_09      171 - 171
      PEF_10      172 - 172
      PEF_11      173 - 173
      PEF_12      174 - 174
      PEF_13      175 - 175
      PEF_14      176 - 176
      PEG_01      177 - 177
      PEG_03      178 - 178
      PEG_04      179 - 179
      PEG_05      180 - 180
      PEG_06      181 - 181
      PEG_07      182 - 182
      PEG_08      183 - 183
      PEG_09      184 - 184
      PEG_10      185 - 185
      PEG_12      186 - 186
      PEG_13      187 - 187
      PEG_14      188 - 188
      PV1ESP      189 - 196
      PV2ESP      197 - 204
      PV3ESP      205 - 212
      PV4ESP      213 - 220
      PV5ESP      221 - 228
      ESPNVL1     229 - 229
      ESPNVL2     230 - 230
      ESPNVL3     231 - 231
      ESPNVL4     232 - 232
      ESPNVL5     233 - 233
      ESPNVBL1    234 - 234
      ESPNVBL2    235 - 235
      ESPNVBL3    236 - 236
      ESPNVBL4    237 - 237
      ESPNVBL5    238 - 238
      ESPNVML1    239 - 239
      ESPNVML2    240 - 240
      ESPNVML3    241 - 241
      ESPNVML4    242 - 242
      ESPNVML5    243 - 243
      WVARSTRR    244 - 246
      W_FSTR1     247 - 257
      W_FSTR2     258 - 268
      W_FSTR3     269 - 279
      W_FSTR4     280 - 290
      W_FSTR5     291 - 301
      W_FSTR6     302 - 312
      W_FSTR7     313 - 323
      W_FSTR8     324 - 334
      W_FSTR9     335 - 345
      W_FSTR10    346 - 356
      W_FSTR11    357 - 367
      W_FSTR12    368 - 378
      W_FSTR13    379 - 389
      W_FSTR14    390 - 400
      W_FSTR15    401 - 411
      W_FSTR16    412 - 422
      W_FSTR17    423 - 433
      W_FSTR18    434 - 444
      W_FSTR19    445 - 455
      W_FSTR20    456 - 466
      W_FSTR21    467 - 477
      W_FSTR22    478 - 488
      W_FSTR23    489 - 499
      W_FSTR24    500 - 510
      W_FSTR25    511 - 521
      W_FSTR26    522 - 532
      W_FSTR27    533 - 543
      W_FSTR28    544 - 554
      W_FSTR29    555 - 565
      W_FSTR30    566 - 576
      W_FSTR31    577 - 587
      W_FSTR32    588 - 598
      W_FSTR33    599 - 609
      W_FSTR34    610 - 620
      W_FSTR35    621 - 631
      W_FSTR36    632 - 642
      W_FSTR37    643 - 653
      W_FSTR38    654 - 664
      W_FSTR39    665 - 675
      W_FSTR40    676 - 686
      W_FSTR41    687 - 697
      W_FSTR42    698 - 708
      W_FSTR43    709 - 719
      W_FSTR44    720 - 730
      W_FSTR45    731 - 741
      W_FSTR46    742 - 752
      W_FSTR47    753 - 763
      W_FSTR48    764 - 774
      W_FSTR49    775 - 785
      W_FSTR50    786 - 796
      W_FSTR51    797 - 807
      W_FSTR52    808 - 818
      W_FSTR53    819 - 829
      W_FSTR54    830 - 840
      W_FSTR55    841 - 851
      W_FSTR56    852 - 862
      W_FSTR57    863 - 873
      W_FSTR58    874 - 884
      W_FSTR59    885 - 895
      W_FSTR60    896 - 906
      W_FSTR61    907 - 917
      W_FSTR62    918 - 928
      W_FSTR63    929 - 939
      W_FSTR64    940 - 950
      W_FSTR65    951 - 961
      W_FSTR66    962 - 972
      W_FSTR67    973 - 983
      W_FSTR68    984 - 994
      W_FSTR69    995 - 1005
      W_FSTR70   1006 - 1016
      W_FSTR71   1017 - 1027
      W_FSTR72   1028 - 1038
      W_FSTR73   1039 - 1049
      W_FSTR74   1050 - 1060
      W_FSTR75   1061 - 1071
      W_FSTR76   1072 - 1082
      W_FSTR77   1083 - 1093
      W_FSTR78   1094 - 1104
      W_FSTR79   1105 - 1115
      W_FSTR80   1116 - 1126
      W_FSTR81   1127 - 1137
      W_FSTR82   1138 - 1148
      W_FSTR83   1149 - 1159
      W_FSTR84   1160 - 1170
      W_FSTR85   1171 - 1181
      W_FSTR86   1182 - 1192
      W_FSTR87   1193 - 1203
      W_FSTR88   1204 - 1214
      W_FSTR89   1215 - 1225
      W_FSTR90   1226 - 1236
      W_FSTR91   1237 - 1247
      W_FSTR92   1248 - 1258
      W_FSTR93   1259 - 1269
      W_FSTR94   1270 - 1280
      W_FSTR95   1281 - 1291
      W_FSTR96   1292 - 1302
      W_FSTR97   1303 - 1313
      W_FSTR98   1314 - 1324
      W_FSTR99   1325 - 1335
      W_FSTR100  1336 - 1346
;




   LABEL
      NACIONAL   = "Variable auxiliar para obtener promedios nacionales"
      ESCUELA    = "Identificador de la escuela"
      ID_ENT     = "Entidad federativa (identificador numrico)"
      NOM_ENT    = "Entidad federativa"
      ID_MOD     = "Estrato escolar o Modalidad educativa (identificador numrico)"
      MOD        = "Estrato escolar o Modalidad educativa"
      ESTRATO    = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
      ENTEST     = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
      ALUMNO     = "Identificador del alumno"
      ID_INSTR   = "Identificador del cuadernillo de examen"
      SEXO       = "Sexo del alumno"
      EDAD_AC    = "Edad en aos cumplidos (al momento de la aplicacin)"
      MES_NAC    = "Mes de nacimiento del alumno"
      EDAD       = "Edad del alumno al mes de mayo de 2014, en aos (al momento de la aplicacin). Incluye los meses cumplidos (decimales)"
      EDAD_ACC   = "Edad en aos cumplidos codificada (con recodificacin y colapsamiento de categoras de la variable EDAD_AC)"
      EDAD_N     = "Edad normativa. Supone el ingreso al primero de primaria con 6 aos cumplidos (o menos) al primero de septiembre"
      EDAD_ANT   = "Edad anticipada. Variable indicadora de los alumnos que ingresaron al primero de primaria con menos de 6 aos cumplidos al primero de septiembre"
      EDAD_EES   = "Extra edad severa. Variable indicadora de los alumnos que tienen dos aos o ms de retraso en el sistema escolar"
      W_ALU      = "Peso muestral o ponderador del alumno"
      DOCENTE    = "Identificador del docente que imparte clases al alumno"
      PEA_01     = "Identificar versos rimados en poesa."
      PEA_02     = "Reconocer los recursos literarios empleados en la poesa."
      PEA_03     = "Identificar el sentido literal de expresiones figuradas."
      PEA_04     = "Identificar el fragmento de un poema donde se manifiestan sentimientos."
      PEA_05     = "Detectar el empleo correcto de signos de interrogacin, admiracin y guin."
      PEA_06     = "Interpretar el juego de palabras que se hace en un chiste."
      PEA_07     = "Identificar las caractersticas generales de las adivinanzas."
      PEA_08     = "Identificar las caractersticas de los textos expositivos: funcin."
      PEA_09     = "Interpretar la informacin que proporciona una imagen a un texto informativo."
      PEA_10     = "Detectar la relacin causa-efecto en un texto expositivo."
      PEA_11     = "Identificar las palabras faltantes con apoyo al conocimiento de familias lxicas."
      PEA_12     = "Reconocer las preguntas de un cuestionario que permiten obtener mayor informacin."
      PEA_13     = "Identificar preguntas abiertas y cerradas."
      PEB_01     = "Identificar el orden cronolgico de la secuencia temporal de un cuento."
      PEB_03     = "Identificar frases que indiquen tiempo."
      PEB_04     = "Interpretar la informacin que proporciona una imagen a un texto literario."
      PEB_05     = "Inferir el significado de palabras desconocidas en textos informativos."
      PEB_06     = "Identificar la informacin relevante para elaborar  notas."
      PEB_07     = "Detectar preguntas pertinentes para recabar informacin de un tema especfico."
      PEB_08     = "Identificar correspondencia entre la informacin vertida en una tabla y la del cuerpo del texto."
      PEB_09     = "Identificar mensajes escritos adaptados de otro con marcas de oralidad."
      PEB_10     = "Elegir la frase escrita para clarificar un mensaje."
      PEB_11     = "Elegir frases escritas correctamente que utilicen punto y seguido y punto final."
      PEB_12     = "Identificar la segmentacin convencional de palabras."
      PEB_13     = "Interpretar smbolos o leyendas que indican peligro, alerta o prohibicin."
      PEC_01     = "Comprender globalmente la trama de un texto literario: cuento."
      PEC_02     = "Identificar caractersticas del personaje principal en cuento."
      PEC_03     = "Seleccionar la adaptacin hecha a una parte de la trama de un cuento."
      PEC_04     = "Identificar frases que indiquen modo."
      PEC_05     = "Detectar los diferentes tipos de textos periodsticos."
      PEC_06     = "Seleccionar informacin para integrarla a un anuncio clasificado."
      PEC_07     = "Elaborar preguntas para guiar la bsqueda de informacin."
      PEC_08     = "Identificar la informacin que puede contener el apartado de un texto informativo."
      PEC_09     = "Resumir informacin central de un prrafo de un texto informativo."
      PEC_10     = "Identificar explicaciones en textos expositivos."
      PEC_11     = "Identificar palabras que indiquen sucesin."
      PEC_13     = "Identificar la redaccin de los reglamentos."
      PED_01     = "Identificar el narrador de texto autobiogrfico."
      PED_02     = "Detectar el uso correcto de la concordancia en un texto escrito."
      PED_03     = "Seleccionar la frase adecuada para eliminar reiteraciones innecesarias en un texto escrito."
      PED_04     = " Identificar las caractersticas generales de las autobiografas."
      PED_05     = "Localizar informacin especfica en fuentes de consulta."
      PED_06     = "Seleccionar el ttulo que organiza la informacin."
      PED_08     = "Identificar las justificacin que da un autor para recomendar un cuento."
      PED_09     = "Seleccionar el esquema de planeacin adecuado para exponer informacin."
      PED_10     = "Localizar informacin especfica dentro de un texto."
      PED_11     = "Seleccionar la informacin contenida en un texto para ampliar la informacin de un tema."
      PED_12     = "Identificar la informacin que agrega una tabla a un texto escrito en prosa."
      PED_13     = "Identificar la tabla que ordena cierta informacin."
      PEE_01     = "Identificar la funcin de los textos periodsticos."
      PEE_03     = "Seleccionar la informacin esencial que le falta a una noticia."
      PEE_04     = "Reconocer el uso correcto de las maysculas al inicio de prrafo y en nombres propios."
      PEE_05     = "Seleccionar materiales de lectura para ampliar informacin."
      PEE_06     = "Anticipar el contenido de un texto por la informacin presentada en la portada."
      PEE_07     = "Identificar informacin especfica en la portada de libro."
      PEE_08     = "Aplicar correctamente el orden alfabtico."
      PEE_09     = "Identificar la utilidad del orden alfabtico."
      PEE_10     = "Interpretar la trama global de un texto literario: fbula."
      PEE_11     = "Interpretar las acciones del personaje principal, con relacin a la enseanza de la moraleja."
      PEE_12     = "Comprender la funcin de la moraleja."
      PEE_13     = "Interpretar el contenido de una fbula."
      PEF_01     = "Identificar el tema de una leyenda o un mito "
      PEF_02     = "Identificar diferencias entre lenguaje oral y la escritura en historieta."
      PEF_03     = "Identificar el orden cronolgico de una narracin."
      PEF_04     = "Seleccionar palabras que utilicen dgrafos para completar correctamente un espacio en blanco."
      PEF_05     = "Reconocer la funcin del cartel publicitario."
      PEF_06     = "Seleccionar frases adjetivas para persuadir."
      PEF_07     = "Identificar la disposicin grfica de las notas periodsticas."
      PEF_08     = "Localizar informacin especfica en una nota informativa."
      PEF_09     = "Seleccionar la descripcin que corresponda a la imagen o ilustracin presentada en un texto periodstico."
      PEF_10     = "Identificar el lenguaje formal de los textos expositivos."
      PEF_11     = "Identificar la justificacin que da un participante en una situacin dilemtica."
      PEF_12     = "Interpretar las contribuciones en la realizacin de tareas conjuntas."
      PEF_13     = "Identificar los pasos de un plan de trabajo."
      PEF_14     = "Distinguir la importancia de la interaccin entre personas en diversos contextos."
      PEG_01     = "Inferir el significado de palabras desconocidas en textos literarios."
      PEG_03     = "Comprender los beneficios de leer literatura escrita en otra cultura."
      PEG_04     = "Resolver dudas ortogrficas con el apoyo del diccionario."
      PEG_05     = "Interpretar la funcin de los diagramas."
      PEG_06     = "Identificar estructura de los instructivos."
      PEG_07     = "Identificar el seguimiento de instrucciones para llevar a cabo un proceso."
      PEG_08     = "Interpretar la secuencia de acciones presentadas en un diagrama."
      PEG_09     = "Complementar el paso que le falta a un diagrama de flujo."
      PEG_10     = "Identificar la funcin de las distintas partes de una receta."
      PEG_12     = "Interpretar informacin contenida en un instructivo."
      PEG_13     = "Identificar las diferencias generales entre discurso directo e indirecto."
      PEG_14     = "Distinguir discurso directo de indirecto empleado en chistes."
      PV1ESP     = "Primer valor plausible de Espaol"
      PV2ESP     = "Segundo valor plausible de Espaol"
      PV3ESP     = "Tercer valor plausible de Espaol"
      PV4ESP     = "Cuarto valor plausible de Espaol"
      PV5ESP     = "Quinto valor plausible de Espaol"
      ESPNVL1    = "Nivel de logro en Espaol. Asociado a PV1ESP. (Cuatro niveles)"
      ESPNVL2    = "Nivel de logro en Espaol. Asociado a PV2ESP. (Cuatro niveles)"
      ESPNVL3    = "Nivel de logro en Espaol. Asociado a PV3ESP. (Cuatro niveles)"
      ESPNVL4    = "Nivel de logro en Espaol. Asociado a PV4ESP. (Cuatro niveles)"
      ESPNVL5    = "Nivel de logro en Espaol. Asociado a PV5ESP. (Cuatro niveles)"
      ESPNVBL1   = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a PV1ESP."
      ESPNVBL2   = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a PV2ESP."
      ESPNVBL3   = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a PV3ESP."
      ESPNVBL4   = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a PV4ESP."
      ESPNVBL5   = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a PV5ESP."
      ESPNVML1   = "Identifica si el alumno pertenece al menos al nivel medio de logro en Espaol. Asociado a PV1ESP."
      ESPNVML2   = "Identifica si el alumno pertenece al menos al nivel medio de logro en Espaol. Asociado a PV2ESP."
      ESPNVML3   = "Identifica si el alumno pertenece al menos al nivel medio de logro en Espaol. Asociado a PV3ESP."
      ESPNVML4   = "Identifica si el alumno pertenece al menos al nivel medio de logro en Espaol. Asociado a PV4ESP."
      ESPNVML5   = "Identifica si el alumno pertenece al menos al nivel medio de logro en Espaol. Asociado a PV5ESP."
      WVARSTRR   = "Identificador del pseudoestrato (1 a 100) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
      W_FSTR1    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR2    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR3    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR4    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR5    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR6    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR7    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR8    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR9    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR10   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR11   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR12   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR13   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR14   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR15   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR16   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR17   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR18   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR19   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR20   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR21   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR22   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR23   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR24   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR25   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR26   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR27   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR28   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR29   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR30   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR31   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR32   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR33   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR34   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR35   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR36   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR37   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR38   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR39   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR40   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR41   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR42   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR43   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR44   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR45   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR46   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR47   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR48   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR49   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR50   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR51   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR52   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR53   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR54   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR55   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR56   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR57   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR58   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR59   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR60   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR61   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR62   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR63   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR64   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR65   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR66   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR67   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR68   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR69   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR70   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR71   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR72   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR73   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR74   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR75   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR76   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR77   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR78   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR79   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR80   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR81   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR82   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR83   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR84   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR85   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR86   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR87   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR88   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR89   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR90   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR91   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR92   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR93   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR94   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR95   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR96   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR97   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR98   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR99   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR100  = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
;


   FORMAT
      NACIONAL   1.
      ESCUELA    4.
      ID_ENT     id_entF.
      NOM_ENT    $char19.
      ID_MOD     id_modF.
      MOD        $modF.
      ESTRATO    $char7.
      ENTEST     $entestF.
      ALUMNO     5.
      ID_INSTR   $char15.
      SEXO       sexoF.
      EDAD_AC    edad_acF.
      MES_NAC    mes_nacF.
      EDAD       edadF.
      EDAD_ACC   edadCF.
      EDAD_N     edadNF.
      EDAD_ANT   edadAF.
      EDAD_EES   edadEF.
      DOCENTE    docenF.
      PEA_01     reactF.
      PEA_02     reactF.
      PEA_03     reactF.
      PEA_04     reactF.
      PEA_05     reactF.
      PEA_06     reactF.
      PEA_07     reactF.
      PEA_08     reactF.
      PEA_09     reactF.
      PEA_10     reactF.
      PEA_11     reactF.
      PEA_12     reactF.
      PEA_13     reactF.
      PEB_01     reactF.
      PEB_03     reactF.
      PEB_04     reactF.
      PEB_05     reactF.
      PEB_06     reactF.
      PEB_07     reactF.
      PEB_08     reactF.
      PEB_09     reactF.
      PEB_10     reactF.
      PEB_11     reactF.
      PEB_12     reactF.
      PEB_13     reactF.
      PEC_01     reactF.
      PEC_02     reactF.
      PEC_03     reactF.
      PEC_04     reactF.
      PEC_05     reactF.
      PEC_06     reactF.
      PEC_07     reactF.
      PEC_08     reactF.
      PEC_09     reactF.
      PEC_10     reactF.
      PEC_11     reactF.
      PEC_13     reactF.
      PED_01     reactF.
      PED_02     reactF.
      PED_03     reactF.
      PED_04     reactF.
      PED_05     reactF.
      PED_06     reactF.
      PED_08     reactF.
      PED_09     reactF.
      PED_10     reactF.
      PED_11     reactF.
      PED_12     reactF.
      PED_13     reactF.
      PEE_01     reactF.
      PEE_03     reactF.
      PEE_04     reactF.
      PEE_05     reactF.
      PEE_06     reactF.
      PEE_07     reactF.
      PEE_08     reactF.
      PEE_09     reactF.
      PEE_10     reactF.
      PEE_11     reactF.
      PEE_12     reactF.
      PEE_13     reactF.
      PEF_01     reactF.
      PEF_02     reactF.
      PEF_03     reactF.
      PEF_04     reactF.
      PEF_05     reactF.
      PEF_06     reactF.
      PEF_07     reactF.
      PEF_08     reactF.
      PEF_09     reactF.
      PEF_10     reactF.
      PEF_11     reactF.
      PEF_12     reactF.
      PEF_13     reactF.
      PEF_14     reactF.
      PEG_01     reactF.
      PEG_03     reactF.
      PEG_04     reactF.
      PEG_05     reactF.
      PEG_06     reactF.
      PEG_07     reactF.
      PEG_08     reactF.
      PEG_09     reactF.
      PEG_10     reactF.
      PEG_12     reactF.
      PEG_13     reactF.
      PEG_14     reactF.
      ESPNVL1    nvlF.
      ESPNVL2    nvlF.
      ESPNVL3    nvlF.
      ESPNVL4    nvlF.
      ESPNVL5    nvlF.
      ESPNVBL1   nvblF.
      ESPNVBL2   nvblF.
      ESPNVBL3   nvblF.
      ESPNVBL4   nvblF.
      ESPNVBL5   nvblF.
      ESPNVML1   nvmlF.
      ESPNVML2   nvmlF.
      ESPNVML3   nvmlF.
      ESPNVML4   nvmlF.
      ESPNVML5   nvmlF.
      WVARSTRR   3.
;



/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
 IF  sexo = 8 THEN  sexo = .M;
 IF  edad_ac = 98 THEN  edad_ac = .M;
 IF  mes_nac = 98 THEN  mes_nac = .M;
 IF  entest = "999" THEN  entest = .S;
 IF  Docente = 99999 THEN  Docente = .S;

 ARRAY perdidos1(5)  sexo edad_acc edad_n edad_ant edad_ant;
 DO  i=1 TO 5;
       IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
 END;

 ARRAY perdidos2(3)  edad edad_ac mes_nac;
 DO  i=1 TO 3;
       IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
 END;



 ARRAY perdidos3(87)
             pea_01 pea_02 pea_03 pea_04 pea_05 pea_06 pea_07 pea_08
             pea_09 pea_10 pea_11 pea_12 pea_13 peb_01 peb_03 peb_04
             peb_05 peb_06 peb_07 peb_08 peb_09 peb_10 peb_11 peb_12
             peb_13 pec_01 pec_02 pec_03 pec_04 pec_05 pec_06 pec_07
             pec_08 pec_09 pec_10 pec_11 pec_13 ped_01 ped_02 ped_03
             ped_04 ped_05 ped_06 ped_08 ped_09 ped_10 ped_11 ped_12
             ped_13 pee_01 pee_03 pee_04 pee_05 pee_06 pee_07 pee_08
             pee_09 pee_10 pee_11 pee_12 pee_13 pef_01 pef_02 pef_03
             pef_04 pef_05 pef_06 pef_07 pef_08 pef_09 pef_10 pef_11
             pef_12 pef_13 pef_14 peg_01 peg_03 peg_04 peg_05 peg_06
             peg_07 peg_08 peg_09 peg_10 peg_12 peg_13 peg_14 ;
 DO  i=1 TO 87;
        IF perdidos3{i} = 5   THEN  perdidos3{i} = .N;
        IF perdidos3{i} = 6   THEN  perdidos3{i} = .N;
        IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
        IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
        IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
 END;
 drop i;
RUN;
